@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+import logging
 
 import os
 import subprocess
@@ -297,7 +297,7 @@ class parse(TestAffectingCommand):
         artifacts.incorporate_parse_results(parse_results)
         self.say("Parsed {0} test results",
                  len(artifacts.bundle["test_runs"][0]["test_results"]))
-        print artifacts.dumps_bundle()
+        logging.debug(artifacts.dumps_bundle())
         if self.args.output:
             if not self.args.skip_attachments:
                 artifacts.attach_standard_files_to_bundle()
