@@ -172,19 +172,18 @@ class RegistryProvider(ITestProvider):
                 if test.test_id in self._cache:
                     raise ValueError("Duplicate test %s declared" % test.test_id)
                 self._cache[test.test_id] = test
-            except IOError, err:
-                logging.warning("Failed to load the " + test_url)
-                if hasattr(e, 'reason'):
-                    logging.warning("WARNING: URL Reason: "+ e.reason)
-                elif hasattr(e, 'code'):
-                    logging.warning('WARNING: URL Error code: ' + e.code)
-                else:
-                    logging.exception("WARNING: Unknown IO error", str(err))
-            except ValueError, err:
-                logging.warning('Error found when parsing the' + test_url)
-            except Exception, err:
-                logging.warning('Failed to load the' + test_url)
-                logging.warning("Unknown exception : " + str(err))
+            except IOError as exc:
+                logging.warning(
+                    "Unable to load test definition from %r: %r", test_url, exc)
+                if hasattr(exc, 'reason'):
+                    logging.warning("Error reason: %r", exc.reason)
+                elif hasattr(exc, 'code'):
+                    logging.warning('Error code: %r', exc.code)
+            except Exception as exc:
+                # This can be a number of things, including URL errors, JSON
+                # errors and validation errors
+                logging.warning('Unable to load test definition from %r: %r', 
+                                test_url, exc)
 
     def __iter__(self):
         self._fill_cache()
