@@ -13,6 +13,18 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+"""
+GLMemPerf is an OpenGL ES 2.0 performance estimation tool that aims to
+measure the memory bandwidth characteristics of a graphics implementation.
+It performs a number of blit style renders using different texture formats,
+sizes, orientations and fragment shaders. The results are given as frames
+per second numbers.
+
+**URL:** http://gitorious.org/meego-graphics/glmemperf
+
+**Default Options:** -e shimage
+"""
+
 
 from lava_test.core.installers import TestInstaller
 from lava_test.core.parsers import TestParser
