@@ -13,6 +13,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+"""
+GtkPerf is an application designed to test GTK+ performance using predefined GTK+ widgets.
+
+**URL:** http://gtkperf.sourceforge.net/
+
+**Default options:** -a -c 500
+"""
+
 import re
 
 from lava_test.core.installers import TestInstaller
